using Lab9.Models;

namespace Lab9.Repositories
{
    public interface IRepository
    {
        public IList<News> GetAllNews();
        public IList<News> GetAllNewsByDate(DateTime date);
        public IList<News> GetAllNewsByCategory(string category);
        public IList<News> GetAllNewsByCategoryAndDate(string category, DateTime date);
        public bool ValidateUser(string username, string password);
        public bool InsertNews(News news);
        public bool UpdateNews(News news);
        public News? GetNewsById(int id);


    }
}
